﻿using Reporter.Properties;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Forms;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;

namespace WpfApplication1.Windows.LoadExcel
{
    /// <summary>
    /// Interaction logic for LoadExcelWindow.xaml
    /// </summary>
    public partial class LoadExcelWindow : Window
    {
        Timer t = new Timer();
        NotifyIcon notifyIcon = new NotifyIcon();
        public LoadExcelWindow()
        {
            InitializeComponent();
            this.ShowInTaskbar = false;
            this.Loaded += new RoutedEventHandler(Window_Loaded);
            SystemTrayIconSetup();
            //set default excel path textBox
            if (!(Settings.Default["DefaultExcelPath"] == ""))
            {
                FileNameTextBox.Text = Settings.Default["DefaultExcelPath"].ToString();
                Settings.Default.Save();
                defaultExcelPathCheckBox.IsChecked = true;
            }

            SetCountDownTimer();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            var desktopWorkingArea = System.Windows.SystemParameters.WorkArea;
            this.Left = desktopWorkingArea.Right - this.Width;
            this.Top = desktopWorkingArea.Bottom - this.Height;
        }

        private void changeDefault_Click(object obj,RoutedEventArgs args)
        {
            this.Close();
            TurnOffSystemTrayIconVisibility();
            Windows.StartWindow.StartWindow startWindow = new StartWindow.StartWindow(triggerMethodChooseNextWindowBasedOnDefault: false);
            startWindow.ShowMainWindow();
        }

        private void chooseExcelButton_Click(object obj,RoutedEventArgs args)
        {
            //Open Microsoft.win32.OpenDialog
            Microsoft.Win32.OpenFileDialog openDialog = new Microsoft.Win32.OpenFileDialog();

            //ShowDialog
            Nullable<bool> end = openDialog.ShowDialog();

            //verify end has choosen proper macro file
            //paste the excel path_append the excel file name @ the end in the choose excel text box 
            if (end == true)
                FileNameTextBox.Text = openDialog.FileName;

            //handling 'Set Default ExcelPath' checkbox
            if (FileNameTextBox.Text != null && FileNameTextBox.Text.Contains(".xl"))
            {
                MessageBoxResult result = System.Windows.MessageBox.Show("Set as Default Excel Path||File", "Choose Default", MessageBoxButton.YesNo);
                switch (result)
                {
                    case MessageBoxResult.Yes:
                        if (Settings.Default["DefaultExcelPath"] == "")
                        {
                            Settings.Default["DefaultExcelPath"] = FileNameTextBox.Text;
                            Settings.Default.Save();
                        }
                        else
                        {
                            Settings.Default["DefaultExcelPath"] = FileNameTextBox.Text;
                            Settings.Default.Save();
                        }

                        defaultExcelPathCheckBox.IsChecked = true;
                        break;

                    case MessageBoxResult.No:
                        defaultExcelPathCheckBox.IsChecked = false;
                        break;
                }               
                
            }

        }

        private void excelUpdated_Checked(object sender, RoutedEventArgs e)
        {
            bool newVal = (excelupdatedCheckBox.IsChecked == true);
            excelupdatedCheckBox.IsChecked = newVal;
        }

        private void excelUpdated_Unchecked(object sender, RoutedEventArgs e)
        {
            bool newVal = (excelupdatedCheckBox.IsChecked == false);
            excelupdatedCheckBox.IsChecked = newVal;
        }

        protected override void OnStateChanged(EventArgs e)
        {
            base.OnStateChanged(e);

            //if Window State is minimized, show ballon tip
            if (this.WindowState == WindowState.Minimized)
                ShowBallonTipInSystemTray();
        }

        public void OpenExcelFile(string excelPath)
        {
            if (FileNameTextBox.Text != null)
            {
                //FileStream file = new FileStream(excelPath, FileMode.Open, FileAccess.ReadWrite);
                Process.Start(excelPath);
            }
            this.Close();
        }

        //timer
        private void SetCountDownTimer()
        {            
            t.Interval = 500;
            t.Tick += new EventHandler(t_Tick);

            //Get and set default timeslot
            DateTime currentTime = DateTime.Now;
            string timeSlotDefaultValue = Settings.Default["TimeSlot"].ToString();
            string[] timeSlot = timeSlotDefaultValue.Split(':');

            DateTime endTime = new DateTime(currentTime.Year, currentTime.Month, currentTime.Day, Int32.Parse(timeSlot[0]), Int32.Parse(timeSlot[1]), 00);
            TimeSpan ts = endTime.Subtract(DateTime.Now);
            Timer.Content = "Status Mail will trigger in-" + ts.ToString("h'hr'm'm's's'");
            if (!(Timer.Content.ToString().Contains("0hr0m0s")))
                t.Start();
        }

        void t_Tick(object sender, EventArgs e)
        {
            //Get and set default timeslot
            DateTime currentTime = DateTime.Now;
            string timeSlotDefaultValue = Settings.Default["TimeSlot"].ToString();
            string[] timeSlot = timeSlotDefaultValue.Split(':');

            DateTime endTime = new DateTime(currentTime.Year, currentTime.Month, currentTime.Day, Int32.Parse(timeSlot[0]), Int32.Parse(timeSlot[1]), 00);
            TimeSpan ts = endTime.Subtract(DateTime.Now);
            Timer.Content = "Status Mail will trigger in-" + ts.ToString("h'hr'm'm's's'");

            //stop timer
            if (Timer.Content.ToString().Contains("0hr0m0s"))
            {
                t.Stop();
                OpenExcelFile(FileNameTextBox.Text);
            }
        }

        #region SystemTray

        public void SystemTrayIconSetup()
        {
            //notify icon
            notifyIcon.Icon = new System.Drawing.Icon("D:\\MyProjects\\DSR\\WpfApplication1\\WpfApplication1\\Resources\\Icons\\sysTrayIcon.ico");
            notifyIcon.Visible = true;
            notifyIcon.DoubleClick += new System.EventHandler(this.notifyIcon_DoubleClick);
            notifyIcon.BalloonTipClicked += new System.EventHandler(this.notifyIcon_DoubleClick);
            notifyIcon.MouseClick += new System.Windows.Forms.MouseEventHandler(this.notifyIcon_MouseClick);
        }

        public void notifyIcon_DoubleClick(object Sender, EventArgs e)
        {
            // Show the form when the user double clicks on the notify icon.               
            if (this.WindowState == WindowState.Minimized)
                this.WindowState = WindowState.Normal;

            // Activate the form.
            this.Activate();
        }

        public void notifyIcon_MouseClick(object Sender, System.Windows.Forms.MouseEventArgs e)
        {
            if (this.WindowState == WindowState.Minimized)
                this.WindowState = WindowState.Normal;

            // Activate the form.
            this.Activate();
        }

        public void TurnOffSystemTrayIconVisibility()
        {
            notifyIcon.Visible = false;
            notifyIcon.Dispose();
        }

        public void ShowBallonTipInSystemTray()
        {
            notifyIcon.ShowBalloonTip(5000, "DSR Tool- Load Excel", "DSR-Load Excel Window is minimized", ToolTipIcon.Info);
        }

        #endregion SystemTray
    }
}
