﻿using Microsoft.Win32;
using Reporter.Properties;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Forms;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Diagnostics;
using WpfApplication1.Common.SystemTray;
using Outlook = Microsoft.Office.Interop.Outlook;

namespace WpfApplication1.Windows.TextEditor
{
    /// <summary>
    /// Interaction logic for TextEditor.xaml
    /// </summary>
    public partial class TextEditor : Window,NotifyIconSetup
    {
        Timer t = new Timer();
        NotifyIcon notifyIcon = new NotifyIcon();
        public TextEditor()
        {
            InitializeComponent();
            this.ShowInTaskbar = false;
            this.Loaded += new RoutedEventHandler(Window_Loaded);
            cmbFontFamily.ItemsSource = Fonts.SystemFontFamilies.OrderBy(f => f.Source);
            cmbFontSize.ItemsSource = new List<double>() { 8, 9, 10, 11, 12, 14, 16, 18, 20, 22, 24, 26, 28, 36, 48, 72 };

            SystemTrayIconSetup();

            SetCountDownTimer();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            var desktopWorkingArea = System.Windows.SystemParameters.WorkArea;
            this.Left = desktopWorkingArea.Right - this.Width;
            this.Top = desktopWorkingArea.Bottom - this.Height;
        }

        private void rtbEditor_SelectionChanged(object sender, RoutedEventArgs e)
        {
            object temp = rtbEditor.Selection.GetPropertyValue(Inline.FontWeightProperty);
            btnBold.IsChecked = (temp != DependencyProperty.UnsetValue) && (temp.Equals(FontWeights.Bold));
            temp = rtbEditor.Selection.GetPropertyValue(Inline.FontStyleProperty);
            btnItalic.IsChecked = (temp != DependencyProperty.UnsetValue) && (temp.Equals(FontStyles.Italic));
            temp = rtbEditor.Selection.GetPropertyValue(Inline.TextDecorationsProperty);
            btnUnderline.IsChecked = (temp != DependencyProperty.UnsetValue) && (temp.Equals(TextDecorations.Underline));

            temp = rtbEditor.Selection.GetPropertyValue(Inline.FontFamilyProperty);
            cmbFontFamily.SelectedItem = temp;
            temp = rtbEditor.Selection.GetPropertyValue(Inline.FontSizeProperty);
            cmbFontSize.Text = temp.ToString();
        }

        //private void Open_Executed(object sender, ExecutedRoutedEventArgs e)
        //{
        //    OpenFileDialog dlg = new OpenFileDialog();
        //    dlg.Filter = "Rich Text Format (*.rtf)|*.rtf|All files (*.*)|*.*";
        //    if (dlg.ShowDialog() == true)
        //    {
        //        FileStream fileStream = new FileStream(dlg.FileName, FileMode.Open);
        //        TextRange range = new TextRange(rtbEditor.Document.ContentStart, rtbEditor.Document.ContentEnd);
        //        range.Load(fileStream, DataFormats.Rtf);
        //    }
        //}

        private void Save_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            Microsoft.Win32.SaveFileDialog dlg = new Microsoft.Win32.SaveFileDialog();
            dlg.Filter = "Rich Text Format (*.rtf)|*.rtf|All files (*.*)|*.*";
            if (dlg.ShowDialog() == true)
            {
                FileStream fileStream = new FileStream(dlg.FileName, FileMode.Create);
                TextRange range = new TextRange(rtbEditor.Document.ContentStart, rtbEditor.Document.ContentEnd);
                range.Save(fileStream, System.Windows.DataFormats.Rtf);
            }
        }

        private void cmbFontFamily_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (cmbFontFamily.SelectedItem != null)
                rtbEditor.Selection.ApplyPropertyValue(Inline.FontFamilyProperty, cmbFontFamily.SelectedItem);
        }

        private void cmbFontSize_TextChanged(object sender, TextChangedEventArgs e)
        {
            rtbEditor.Selection.ApplyPropertyValue(Inline.FontSizeProperty, cmbFontSize.Text);
        }

        private void changeDefault_Click(object obj, RoutedEventArgs args)
        {
            this.Close();
            TurnOffSystemTrayIconVisibility();
            Windows.StartWindow.StartWindow startWindow = new StartWindow.StartWindow(triggerMethodChooseNextWindowBasedOnDefault: false);
            startWindow.ShowMainWindow();
        }

        private void changeMailDefault_Click(object obj, RoutedEventArgs args)
        {
            Windows.TextEditor.MailItemSettings.MailItemSettings mailItemSettings = new Windows.TextEditor.MailItemSettings.MailItemSettings();
            mailItemSettings.ShowInTaskbar = false;
            mailItemSettings.Show();
        }

        protected override void OnStateChanged(EventArgs e)
        {
            base.OnStateChanged(e);

            //if Window State is minimized, show ballon tip
            if (this.WindowState == WindowState.Minimized)
                showBallonTipInSystemTray();
        }

        private void rtbEditor_TextChanged(object sender, TextChangedEventArgs e)
        {
            string[] mailItemDefaults = { "MailTo", "MailCc", "MailSubject", "MailBody1", "MailBody2", "MailSignature" };
            string validationText = null;
            bool promptErrorMessage = false;
            for (int i = 0; i < mailItemDefaults.Length; i++)
            {
                if (Settings.Default[mailItemDefaults[i]].ToString() == "")
                {
                    validationText = validationText + mailItemDefaults[i] + ",";
                    promptErrorMessage = true;
                }
            }

            //show error message dialog
            if (promptErrorMessage)
                System.Windows.MessageBox.Show("Please enter values for the Textboxes: " + validationText + " in MailItemDefault Window.");
        }

        //timer
        private void SetCountDownTimer()
        {
            t.Interval = 500;
            t.Tick += new EventHandler(t_Tick);

            //Get and set default timeslot
            DateTime currentTime = DateTime.Now;
            string timeSlotDefaultValue = Settings.Default["TimeSlot"].ToString();
            string[] timeSlot = timeSlotDefaultValue.Split(':');

            DateTime endTime = new DateTime(currentTime.Year, currentTime.Month, currentTime.Day, Int32.Parse(timeSlot[0]), Int32.Parse(timeSlot[0]),00);
            TimeSpan ts = endTime.Subtract(DateTime.Now);
            Timer.Content = ts.ToString("h'hr'm'm's's'");
            if (!(Timer.Content.ToString().Contains("0hr0m0s")))
                t.Start();
        }

        void t_Tick(object sender, EventArgs e)
        {
            //Get and set default timeslot
            DateTime currentTime = DateTime.Now;
            string timeSlotDefaultValue = Settings.Default["TimeSlot"].ToString();
            string[] timeSlot = timeSlotDefaultValue.Split(':');

            DateTime endTime = new DateTime(currentTime.Year, currentTime.Month, currentTime.Day, Int32.Parse(timeSlot[0]), Int32.Parse(timeSlot[1]), 00);
            TimeSpan ts = endTime.Subtract(DateTime.Now);
            Timer.Content = ts.ToString("h'hr'm'm's's'");

            //stop timer
            if (Timer.Content.ToString().Contains("0hr0m0s"))
            {
                t.Stop();
                SendMailTextEditor();
            }
        }

        private void SendMailTextEditor()
        {
            Process[] isOutlookRunning = Process.GetProcessesByName("Outlook");
                        
            //outlook mail initial setup
            if (isOutlookRunning.Length > 0)
                Console.Write("No need to open outlook, as outlook is running in this machine");
            else
            {
                Process.Start(@"C:\Program Files\Microsoft Office\Office14\OUTLOOK.exe");
                isOutlookRunning = Process.GetProcessesByName("Outlook");
                //outlook mail initial setup
                if (isOutlookRunning.Length > 0)
                    Console.Write("Outlook opened and it is running in this machine");
            }

            Outlook.Application app = new Outlook.Application();
            Microsoft.Office.Interop.Outlook.MailItem mail = (Outlook.MailItem)app.CreateItem(Outlook.OlItemType.olMailItem);

            //mail setup
            string[] mailItemDefaults = { "MailTo", "MailCc", "MailSubject", "MailBody1", "MailBody2", "MailSignature" };

            mail.To = Settings.Default[mailItemDefaults[0]].ToString();
            mail.CC = Settings.Default[mailItemDefaults[1]].ToString();
            mail.Subject = Settings.Default[mailItemDefaults[2]].ToString();
            mail.Body = Settings.Default[mailItemDefaults[3]].ToString() + System.Environment.NewLine + Settings.Default[mailItemDefaults[4]].ToString()
                + System.Environment.NewLine + System.Environment.NewLine + new TextRange(rtbEditor.Document.ContentStart, rtbEditor.Document.ContentEnd).Text
                + System.Environment.NewLine + Settings.Default[mailItemDefaults[5]].ToString().Split(',')[0] + ","
                + System.Environment.NewLine + Settings.Default[mailItemDefaults[5]].ToString().Split(',')[1];

            mail.Send();

            this.Close();

            //close this application process(background)
            Process[] isReporterRunning = Process.GetProcessesByName("Reporter");

            //outlook mail initial setup
            if (isReporterRunning.Length > 0)
                Console.Write("Reporter closed successfully.");
        }

        #region SystemTray

        public void SystemTrayIconSetup()
        {
            //notify icon
            notifyIcon.Icon = new System.Drawing.Icon("D:\\MyProjects\\DSR\\WpfApplication1\\WpfApplication1\\Resources\\Icons\\sysTrayIcon.ico");
            notifyIcon.Visible = true;
            notifyIcon.DoubleClick += new System.EventHandler(this.NotifyIcon_DoubleClick);
            notifyIcon.BalloonTipClicked += new System.EventHandler(this.NotifyIcon_DoubleClick);
            notifyIcon.MouseClick += new System.Windows.Forms.MouseEventHandler(this.NotifyIcon_MouseClick);
        }

        public void NotifyIcon_DoubleClick(object Sender, EventArgs e)
        {
            // Show the form when the user double clicks on the notify icon.               
            if (this.WindowState == WindowState.Minimized)
                this.WindowState = WindowState.Normal;

            // Activate the form.
            this.Activate();
        }

        public void NotifyIcon_MouseClick(object Sender, System.Windows.Forms.MouseEventArgs e)
        {
            if (this.WindowState == WindowState.Minimized)
                this.WindowState = WindowState.Normal;

            // Activate the form.
            this.Activate();
        }

        public void TurnOffSystemTrayIconVisibility()
        {
            notifyIcon.Visible = false;
            notifyIcon.Dispose();
        }

        public void showBallonTipInSystemTray()
        {
            notifyIcon.ShowBalloonTip(5000, "DSR Tool- Text Editor", "DSR-Text Editor Window is minimized", ToolTipIcon.Info);
        }

        #endregion SystemTray        
    }
}
